<?php
require_once __DIR__ .'/../../config.php';

$success = false;
$error   = null;
// send the emails
if ( isset($_POST) && isset($_POST['id']) && count($_POST) > 0 ) {
    /**
     * Send the mail
     *
     * @return bool
     */
    function sendMail()
    {
        $name = $_POST['c_name'];
        $email     = $_POST['c_email'];
        $tel       = $_POST['c_tel'];
        $msg       = $_POST['c_msg'];

        $headers = "From: Edugate Chile Website<latam@edugate.com.au>\r\n";
        $headers .= "Reply-To: no-reply@edugate.com.au\r\n";
        $headers .= "MIME-Version: 1.0\r\n";
        $headers .= "Content-Type: text/html; charset=ISO-8859-1\r\n";
        ob_start();
        $args = [
            'name' => $name,
            'email'     => $email,
            'tel'       => $tel,
            'msg'       => $msg,
            'post' => $_POST,
            'ip' => getClientIP(),
            'detectedCountry' => detectCountryFromIp(getClientIP()),
            'referredBy' => getReferrer(),
        ];
        include( __DIR__ . '/contact-form-email-template.php' );
        $content = ob_get_clean();

        return mail(SEND_MAIL_TO, 'A new client enquiry', $content, $headers);

    }


    if ( isValidSession() ) {
        try {
//            verifyRecaptcha();
            if ( sendMail() ) {
                setSessionTimer();
                if ( expectsJson() ) {
                    jsonResponse(['success' => true]);
                }
                else {
                    $success = true;
                    $error   = false;
                }
            }
            else {
                if ( expectsJson() ) {
                    jsonResponse(['success' => false, 'error' => 'Something went wrong sending your email'], 505);
                }
                else {
                    $success = false;
                    $error   = 'Something went wrong sending your email';
                }
            }
        }catch (Exception $e){
            $success = false;
            $error   = $e->getMessage();
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <?php loadEsComponent('head-seo', ['title' => 'Mudarse a Australia | El Proceso', 'description' => 'Ofreciendo un detallado proceso paso a paso. Estos son los pasos que seguimos para ayudarte a mudarte a Australia']) ?>
    <?php include_once __DIR__ . '/../partials/head.php' ?>
    <?php include_once __DIR__ .'/../partials/inner-page-banner-styles.php'
    ?>
</head>

<body>
<?php include_once __DIR__ . '/../partials/header.php' ?>
<section class="inner-page-banner relative">
    <img src="<?= IMAGES_URL ?>banners/edugate-latam-contact-us.jpg"
         alt="Comienza tu solicitud para estudiar en Australia" class="inner-banner-image has-bg animated">
    <div class="darken-bg"></div>
    <div class="container h-100 relative">
        <div class="row d-flex full-height align-items-end">
            <div class="col-md-8 col-lg-6 offset-lg-1">
                <div class="hero-banner-text-container">
                    <h1 class="primary hero-text custom-font thick text-white">
                        Iniciar<br><span class="hero-small-in">Tu</span><br>Solicitud
                    </h1>
                    <div class="spacer-invis"></div>
                    <div class="spacer-tiny"></div>
                </div>
            </div>
        </div>
        <?php include __DIR__ . '/../partials/banner-socials.php' ?>
    </div>
</section>
<section class="section first-section">
    <div class="container">
        <div class="row">
            <div class="col">
                <?php if($error): ?>
                    <div class="card alert alert-danger" style="font-size: 0.9em">
                        <p class="custom-font">Ha ocurrido un error</p>
                        <p><?= $error ?></p>
                    </div>
                    <div class="spacer-invis"></div>
                <?php endif; ?>
                <?php if($success): ?>
                    <div class="card alert alert-success custom-font" style="font-size: 0.9em">
                        <p style="margin: 10px 0">Tu mensaje se ha enviado con éxito</p>
                    </div>
                    <div class="spacer-invis"></div>
                <?php endif; ?>
            </div>
        </div>
        <div class="row">
            <div class="col">
                <?php loadEsComponent('section-title', ['title' => 'INICIA TU<br>PROCESO DE SOLICITUD', 'classes' => '']) ?>
                <div class="spacer-tiny"></div>
                <p class="h4">Para comenzar tu viaje a Australia, por favor completa los detalles a continuación y uno de nuestros amables expertos se pondrá en contacto contigo con más información.</p>
                <p class="h4">Solo necesitamos obtener un poco más de información de tu parte para empezar:</p>
            </div>
        </div>
        <div class="spacer-invis"></div>
        <div class="row">
            <div class="col-lg-10 col-xl-8 offset-lg-1 offset-xl-2">
                <form method="post" onsubmit="return checkMandatory()">
                    <input type="hidden" name="id" value="<?= session_id() ?>"/>
                    <div class="contact-form-container">
                        <div class="mb-4">
                            <label for="c_name" class="form-label">Nombre *</label>
                            <input required class="input form-control animated" placeholder="Tu nombre completo"
                                   name="c_name" id="c_name" type="text">
                        </div>

                        <div class="mb-4">
                            <label for="c_tel" class="form-label">Teléfono *</label>
                            <input required class="input form-control animated" placeholder="Tu número de teléfono o móvil"
                                   name="c_tel" id="c_tel" type="tel">
                        </div>

                        <div class="mb-4">
                            <label for="c_email" class="form-label">Email *</label>
                            <input required class="input form-control animated" placeholder="Tu email"
                                   name="c_email" id="c_email" type="email">
                        </div>

                        <div class="mb-4">
                            <label for="when_to_travel" class="form-label">¿Cuándo planeas viajar a Australia?</label>
                            <select class="input form-control animated" name="when_to_travel" id="when_to_travel">
                                <option value="ASAP">Tan pronto como sea posible</option>
                                <option value="In the next 1 - 3 months">En los próximos 1 - 3 meses</option>
                                <option value="In the next 3 - 12 months">En los próximos 3 - 12 meses</option>
                                <option value="In the next 1 - 2 years">En los próximos 1 - 2 años</option>
                                <option value="Not sure">No estoy seguro</option>
                            </select>
                        </div>

                        <div class="mb-4">
                            <label for="how_long_to_stay" class="form-label">¿Cuánto tiempo te gustaría vivir y estudiar en Australia?</label>
                            <select class="input form-control animated" name="how_long_to_stay" id="how_long_to_stay">
                                <option value="Undecided">Indeciso</option>
                                <option value="Up to 6 months">Hasta 6 meses</option>
                                <option value="1 - 2 years">1 - 2 años</option>
                                <option value="Up to 5 years">Hasta 5 años</option>
                                <option value="As long as I can stay">Todo el tiempo que pueda quedarme</option>
                            </select>
                        </div>

                        <div class="mb-4">
                            <label for="what_city" class="form-label">¿En qué ciudad te gustaría vivir y estudiar?</label>
                            <select class="input form-control animated" name="what_city" id="what_city">
                                <option value="Not Sure">No estoy seguro</option>
                                <option value="Sydney (NSW)">Sydney (NSW)</option>
                                <option value="Melbourne (VIC)">Melbourne (VIC)</option>
                                <option value="Brisbane (QLD)">Brisbane (QLD)</option>
                                <option value="Gold Coast (QLD)">Gold Coast (QLD)</option>
                                <option value="Canberra (ACT)">Canberra (ACT)</option>
                                <option value="Adelaide (SA)">Adelaide (SA)</option>
                                <option value="Hobart (TAS)">Hobart (TAS)</option>
                                <option value="Perth (WA)">Perth (WA)</option>
                            </select>
                        </div>

                        <div class="mb-4">
                            <label for="with_family" class="form-label">¿Tienes planeado venir con algún compañero o miembro de la familia?</label>
                            <select class="input form-control animated" name="with_family" id="with_family">
                                <option value="No">No</option>
                                <option value="Yes">Sí</option>
                            </select>
                        </div>

                        <div class="mb-4">
                            <label for="heard_about_us" class="form-label">¿Cómo escuchaste de nosotros?</label>
                            <select class="input form-control animated" name="heard_about_us" id="heard_about_us">
                                <option value="Google">Google</option>
                                <option value="Instagram">Instagram</option>
                                <option value="Facebook">Facebook</option>
                                <option value="Friend">Amigo</option>
                                <option value="Referral">Referencia</option>
                                <option value="Student">Estudiante</option>
                                <option value="Other">Otro</option>
                            </select>
                        </div>

                        <div class="mb-3">
                            <label for="c_msg" class="form-label">¿Hay algo más que te gustaría agregar?</label>
                            <textarea required class="input form-control animated" name="c_msg"
                                      id="c_msg" rows="4"></textarea>
                        </div>
                    </div>
                    <div class="spacer-invis"></div>
                    <button class="btn btn-dark btn-hero btn-rounded text-uppercase" id="sub-btn">Enviar</button>
                </form>
            </div>
        </div>
    </div>
</section>


<?php include_once __DIR__ . '/../partials/footer.php' ?>
<script>


  var _canSub;

  function enSub() {
    _canSub = true;
    $('#sub-btn').removeClass('disabled').prop('disabled', false)
  }
  function diSub() {
    _canSub = false;
    $('#sub-btn').addClass('disabled').prop('disabled', true)
  }

  function checkMandatory(){
    var $fname = $('#c_name').val();
    var $email = $('#c_email').val();
    var $msg = $('#c_msg').val();
    if ( !$fname || !$email ) {
      alert('Please enter all the required information before submitting');
      return false;
    }
    if ( !validateEmail($email) ) {
      alert('Please enter valid email address!');
      return false;
    }
    if ( $fname.length < 2 ) {
      alert('Please enter all the required information before submitting');
      return false;
    }

    // if ($msg.length < 10) {
    //   alert('Please enter all the required information before submitting');
    //   return false;
    // }

    return true;
  }
  function validateEmail(email) {
    var re = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
    return re.test(email);
  }

</script>
</body>
</html>
