<?php
/**
 * Turn on error reporting for demo
 */
if (IS_DEMO) {
    ini_set('display_errors', '1');
    ini_set('display_startup_errors', '1');
    error_reporting(E_ALL);
}

/**
 * Load a component file with parameters
 *
 * @param $component
 * @param array $variables
 */
function loadComponent($component, array $variables = [])
{
    ob_start();
    foreach ($variables as $key => $value) {
        $$key = $value;
    }
    $componentFileName = strpos(strtolower($component), '.php') !== false ? $component : $component. '.php';
    include (__DIR__.'/partials/components/'.$componentFileName);
    echo ob_get_clean();
}

/**
 * Load a component file with parameters
 *
 * @param $component
 * @param array $variables
 */
function loadEsComponent($component, array $variables = [])
{
    ob_start();
    foreach ($variables as $key => $value) {
        $$key = $value;
    }
    $componentFileName = strpos(strtolower($component), '.php') !== false ? $component : $component. '.php';
    include (__DIR__.'/es/partials/components/'.$componentFileName);
    echo ob_get_clean();
}

/**
 * Verify an array and check for needle
 *
 * @param $needle
 * @param $array
 *
 * @return bool
 */
function arrayContains($needle, $array)
{
    return isset($array) && is_array($array) && in_array($needle, $array);
}

/**
 * Check if the request expects JSON
 *
 * @return bool
 */
function expectsJson()
{
    return $_SERVER['HTTP_ACCEPT'] == 'application/json';
}

/**
 * Respond with json data
 *
 * @param $data
 * @param int $statusCode
 */
function jsonResponse($data, $statusCode = 200)
{
    ob_clean();
    header_remove();
    header("Content-type: application/json; charset=utf-8");
    http_response_code($statusCode);
    echo json_encode($data);
    exit();
}

/**
 * Check the session
 *
 * @return bool
 */
function isValidSession()
{
    global $error, $success;
    if (!isset($_POST['id']) || $_POST['id'] !== session_id()) {
        if (expectsJson()) {
            jsonResponse([
                'success' => false,
                'data' => [],
                'error' => 'You have already sent us a contact request'
            ], 500);
            return false;
        }
        $error = 'You have already sent us a contact request';
        $success = false;
        return false;
    }

    if (isset($_SESSION[SESSION_CONTACT_TIME_VAR_NAME]) && time() < $_SESSION[SESSION_CONTACT_TIME_VAR_NAME]){
        // too early to send
        if (expectsJson()) {
            jsonResponse([
                'success' => false,
                'data' => [],
                'error' => 'You have already sent us a contact request'
            ], 500);
            return false;
        }
        else {
            $error = 'You have already sent us a contact request';
            $success = false;
            return false;
        }
    }
    return true;
}

/**
 * Set the session timer once we send successfully
 */
function setSessionTimer()
{
    $_SESSION[SESSION_CONTACT_TIME_VAR_NAME] = time() + SEND_MAIL_EVERY;
}

/**
 * Redirect
 *
 * @param $url
 */
function redirect($url = SITE_URL)
{
    header('Location: ' . $url);
    die();
}



/**
 * Verifies the recaptcha
 *
 * @return bool
 * @throws \Exception
 */
function verifyRecaptcha()
{
    if (!isset( $_POST )) {
        throw new Exception('No request parameter were detected');
    }
    if (!isset($_POST['g-recaptcha-response']) || empty($_POST['g-recaptcha-response'])) {
        throw new Exception('Missing parameters');
    }

    $options = [
        'secret' => GOOGLE_RECAPTCHA_SECRET,
        'response' => $_POST['g-recaptcha-response'],
        'remoteip' => getClientIP()
    ];
    $url = 'https://www.google.com/recaptcha/api/siteverify';
    $response = curlCall($url, $options);

    $json = json_decode($response, true);
    if (!array_key_exists('success', $json) || $json['success'] !== true) {
        throw new Exception('You cannot register');
    }

    return true;
}

/**
 * Service Function to call curl
 *
 * @param $url
 * @param array $parameter
 * @param bool $post
 *
 * @return array|mixed
 * @throws \Exception
 */

if (!function_exists('curlCall')){
    function curlCall( $url, $parameter = [], $post = true )
    {
        try {
            $ch = curl_init();
            curl_setopt( $ch, CURLOPT_RETURNTRANSFER, 1 );
            curl_setopt( $ch, CURLOPT_TIMEOUT, 30 );
            if ( $post === true ) {
                curl_setopt( $ch, CURLOPT_POST, 1 );
                curl_setopt( $ch, CURLOPT_POSTFIELDS, $parameter );
            }
            else {
                $url .= '?' . http_build_query( $parameter );
            }
            curl_setopt( $ch, CURLOPT_URL, $url );
            $result = curl_exec( $ch );
            curl_close( $ch );

            return $result;
        } catch ( Exception $exception ) {
            throw $exception;
        }
    }

}

/**
 * Gets the client IP
 *
 * @return string
 */
if (!function_exists('getClientIP')) {
    function getClientIP()
    {
        if ( isset( $_SERVER['HTTP_CLIENT_IP'] ) ) {
            $ip = $_SERVER['HTTP_CLIENT_IP'];
        }

        else if ( isset( $_SERVER['HTTP_X_FORWARDED_FOR'] ) ) {
            $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
        }
        else if ( isset( $_SERVER['HTTP_X_FORWARDED'] ) ) {
            $ip = $_SERVER['HTTP_X_FORWARDED'];
        }
        else if ( isset( $_SERVER['HTTP_FORWARDED_FOR'] ) ) {
            $ip = $_SERVER['HTTP_FORWARDED_FOR'];
        }
        else if ( isset( $_SERVER['HTTP_FORWARDED'] ) ) {
            $ip = $_SERVER['HTTP_FORWARDED'];
        }
        else if ( isset( $_SERVER['REMOTE_ADDR'] ) ) {
            $ip = $_SERVER['REMOTE_ADDR'];
        }
        else {
            $ip = 'UNKNOWN';
        }
        return $ip;
    }
}


if (!function_exists('detectCountryFromIp')){
    /**
     * Detect the country from IP
     *
     * @param $ip
     *
     * @return null
     */
    function detectCountryFromIp($ip){
        try {
            $response = curlCall('http://ip-api.com/json/'.$ip, [], false);
            $decoded = json_decode($response, true);
            return isset($decoded) && $decoded['status'] === 'success' ? $decoded['country'] : null;
        } catch (\Exception $e){
            // var_dump($e->getMessage());
            return null;
        }
    }
}

if (!function_exists('setCookieAndSession')) {
    /**
     * Sets the cookies and session
     *
     * @param $name
     * @param $value
     * @param int $duration
     */
    function setCookieAndSession($name, $value, $duration = 86400)
    {
        setcookie($name, $value, time() + $duration, "/");
        if (!session_id()){
            session_start();
        }
        $_SESSION[$name] = $value;
    }
}


if (!function_exists('getCookieOrSession')){
    /**
     * Get the value from session or cookie
     *
     * @param $name
     *
     * @return bool
     */
    function getCookieOrSession($name)
    {
        return $_SESSION[$name] ?? (
            $_COOKIE[$name] ?? false
            );
    }
}

if (!function_exists('checkReferrer')) {
    /**
     * Check the referring person
     */
    function checkReferrer()
    {
        $referrer = false;
        // check if it is provided (or renewed)
        if ( isset($_GET['egr']) ) {
            $referrer = $_GET['egr'];
        }

        if ( ! $referrer ) {
            $referrer = getCookieOrSession('__eg_r');
        }

        if ( $referrer !== false && !empty($referrer) ) {
            setCookieAndSession('__eg_r', $referrer);
        }
    }
}

if (!function_exists('getReferrer')) {
    /**
     * Check the referring person
     */
    function getReferrer()
    {
        $code = getCookieOrSession('__eg_r');
        if ($code) {
            $referrers = [
                'LWT5B9' => 'Victor',
                'EX0QWB' => 'Matias',
                'S0PT6Q' => 'Nathan',
                'W2API0' => 'Mike',
                'YF1WP2' => 'Rami',
            ];
            return array_key_exists($code, $referrers) ? $referrers[$code] : false;
        }
        return false;
    }
}